File list - MediaWiki

Jump to content

# File list

Help

This special page shows all uploaded files.

File list
Items per page:
Username:
Include old versions of files
First pagePrevious page Next page Last page

Date | Name | Thumbnail | Size | User | Description
--- | --- | --- | --- | --- | ---
10:33, 2 December 2006 | Example.jpg (file) |  | 60 KB | Bdk | smaller version
21:00, 24 February 2007 | BadImageList.png (file) |  | 51 KB | Robchurch | Crop whitespace from the right of the screenshot
10:36, 30 April 2007 | M-fi-recentchanges.png (file) |  | 130 KB | Cimon Avaro | screencapture for the PD-helpfiles
14:54, 14 May 2007 | NiceCategoryList2 extension example.jpg (file) |  | 28 KB | JohanTheGhost | Example image (partial screenshot) demonstrating the NiceCategoryList2 extension. Made by me, JohanTheGhost, 14 May, 2007.
15:56, 15 May 2007 | NiceCategoryList2 extension default.jpg (file) |  | 23 KB | JohanTheGhost | == Summary == Example image (partial screenshot) demonstrating the NiceCategoryList2 extension in its default mode. Made by me, JohanTheGhost, 15 May, 2007. == Licensing == {{GFDL}}
15:57, 15 May 2007 | NiceCategoryList2 extension full.jpg (file) |  | 20 KB | JohanTheGhost | == Summary == Example image (partial screenshot) demonstrating the NiceCategoryList2 extension used to generate a full listing. Made by me, JohanTheGhost, 15 May, 2007. == Licensing == {{GFDL}}
03:06, 24 June 2007 | TinyMCE MW.PNG (file) |  | 124 KB | JoeSox | TinyMCE_MW extension Screenshots

First pagePrevious page Next page Last page
Retrieved from "https://www.mediawiki.org/wiki/Special:ListFiles"